==> gazie7.30.zip: gazie/modules/magazz/menu.italian.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
$transl['magazz'] = array('name' => "Magazzino",
                          'title' => "Gestione Magazzino",
                          'm2' => array( 1 =>array("Gestione Articoli di Magazzino","Merci/Servizi"),
                                         2 =>array("Gestione Categorie Merceologiche","Cat.Merceologiche"),
                                         3 =>array("Giornale di Magazzino","Movimenti"),
                                         4 =>array("Causali di Magazzino","Causali"),
                                         5 =>array("Selezione articoli per la stampa del listino","Listini"),
                                         6 =>array("Modifica i prezzi degli articoli","Modifica prezzi"),
                                         7 =>array("Selezione articoli per la creazione del depliant","Catalogo"),
                                         8 =>array("Statistiche del magazzino","Statistiche"),
                                         9 =>array("Gestione Raggruppamenti Statistici","Raggr.Statistici")
                                         ),
                          'm3' => array( 1 =>array("Inserisci un nuovo articolo","Nuova merce/servizio"),
                                         2 =>array("Inserisci un nuova categoria merceologica","Nuova categoria merceologica"),
                                         3 =>array("Inserisci un nuovo movimento di magazzino","Nuovo movimento di magazzino"),
                                         4 =>array("Stampa schedari articoli di magazzino","Stampa schedari articoli di magazzino"),
                                         5 =>array("Stampa giornale di magazzino","Stampa giornale di magazzino"),
                                         6 =>array("Generazione movimenti di magazzino da documenti","Genera movimenti di magazzino"),
                                         7 =>array("Inserisci una nuova causale di magazzino","Nuova causale di magazzino"),
                                         8 =>array("Rivalutazione esistente articoli","Rivalutazione esistente"),
                                         9 =>array("Inventario di magazzino","Inventario di magazzino"),
                                         10 =>array("Documenti e/o certificazioni prodotti","Documenti e/o certificazioni"),
                                         11 =>array("Modifica aliquota IVA degli articoli","Cambio IVA articoli"),
                                         12 =>array("Inserisci un nuovo raggruppamento statistico","Nuovo Raggruppamento statistico"),
                                         13 =>array("Situazione di Magazzino","Visualizza situazione di magazzino")

                                      )
                          );
?>

==> gazie8.00.zip: gazie/modules/magazz/menu.italian.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
$transl['magazz'] = array('name' => "Magazzino",
                          'title' => "Gestione Magazzino",
                          'm2' => array( 1 =>array("Gestione Articoli di Magazzino","Merci/Servizi"),
                                         2 =>array("Gestione Categorie Merceologiche","Cat.Merceologiche"),
                                         3 =>array("Giornale di Magazzino","Movimenti"),
                                         4 =>array("Causali di Magazzino","Causali"),
                                         5 =>array("Selezione articoli per la stampa del listino","Listini"),
                                         6 =>array("Modifica i prezzi degli articoli","Modifica prezzi"),
                                         7 =>array("Selezione articoli per la creazione del depliant","Catalogo"),
                                         8 =>array("Statistiche del magazzino","Statistiche"),
                                         9 =>array("Gestione Raggruppamenti Statistici","Raggr.Statistici"),
                                         10 =>array("Gestione Magazzini","Magazzini")
                                         ),
                          'm3' => array( 1 =>array("Inserisci un nuovo articolo","Nuova merce/servizio"),
                                         2 =>array("Inserisci un nuova categoria merceologica","Nuova categoria merceologica"),
                                         3 =>array("Inserisci un nuovo movimento di magazzino","Nuovo movimento di magazzino"),
                                         4 =>array("Stampa schedari articoli di magazzino","Stampa schedari articoli di magazzino"),
                                         5 =>array("Stampa giornale di magazzino","Stampa giornale di magazzino"),
                                         6 =>array("Generazione movimenti di magazzino da documenti","Genera movimenti di magazzino"),
                                         7 =>array("Inserisci una nuova causale di magazzino","Nuova causale di magazzino"),
                                         8 =>array("Rivalutazione esistente articoli","Rivalutazione esistente"),
                                         9 =>array("Inventario di magazzino","Inventario di magazzino"),
                                         10 =>array("Documenti e/o certificazioni prodotti","Documenti e/o certificazioni"),
                                         11 =>array("Modifica aliquota IVA degli articoli","Cambio IVA articoli"),
                                         12 =>array("Inserisci un nuovo raggruppamento statistico","Nuovo Raggruppamento statistico"),
                                         13 =>array("Situazione di Magazzino","Visualizza situazione di magazzino"),
                                         14 =>array("Inserisci un nuovo gruppo","Inserisci nuovo gruppo"),
                                         15 =>array("Inserisci un nuovo magazzino","Inserisci nuovo magazzino")
                                      )
                          );
?>
